@@ -10,10 +10,10 @@ require 'async/http/endpoint'
 protocol = Async::HTTP::Protocol::HTTP2
 endpoint = Async::HTTP::Endpoint.parse('http://127.0.0.1:9222', reuse_port: true)
 
-Async.logger.level = Logger::DEBUG
+Console.logger.level = Logger::DEBUG
 
 Async do
-	server = Async::HTTP::Server.for(endpoint, protocol) do |request|
+	server = Async::HTTP::Server.for(endpoint, protocol: protocol) do |request|
 		Protocol::HTTP::Response[200, {}, request.body]
 	end
 	
