@@ -48,7 +48,7 @@ RSpec.shared_examples_for Async::HTTP::Proxy do
 	
 	context 'CONNECT' do
 		let(:server) do
-			Async::HTTP::Server.for(endpoint, protocol: protocol) do |request|
+			Async::HTTP::Server.for(@bound_endpoint) do |request|
 				Async::HTTP::Body::Hijack.response(request, 200, {}) do |stream|
 					chunk = stream.read
 					stream.close_read
@@ -77,7 +77,7 @@ RSpec.shared_examples_for Async::HTTP::Proxy do
 	
 	context 'echo server' do
 		let(:server) do
-			Async::HTTP::Server.for(endpoint, protocol: protocol) do |request|
+			Async::HTTP::Server.for(@bound_endpoint) do |request|
 				expect(request.path).to be == "localhost:1"
 				
 				Async::HTTP::Body::Hijack.response(request, 200, {}) do |stream|
@@ -130,7 +130,7 @@ RSpec.shared_examples_for Async::HTTP::Proxy do
 	
 	context 'proxied client' do
 		let(:server) do
-			Async::HTTP::Server.for(endpoint, protocol: protocol) do |request|
+			Async::HTTP::Server.for(@bound_endpoint) do |request|
 				expect(request.method).to be == "CONNECT"
 				
 				unless authorization_lambda.call(request)
@@ -181,7 +181,7 @@ RSpec.shared_examples_for Async::HTTP::Proxy do
 			end
 		end
 		
-		let(:authorization_lambda) { ->(request) { true } }
+		let(:authorization_lambda) { ->(request) {true} }
 		
 		it 'can get insecure website' do
 			endpoint = Async::HTTP::Endpoint.parse("http://www.google.com")
@@ -198,6 +198,8 @@ RSpec.shared_examples_for Async::HTTP::Proxy do
 			expect(proxy_client.pool).to_not be_empty
 			proxy_client.close
 			expect(proxy_client.pool).to be_empty
+			
+			pp client
 		end
 		
 		it 'can get secure website' do
